==> python_spoj-0.5.tar.gz: python_spoj-0.5/setup.py <==
"""
An spoj library for python
"""
from setuptools import find_packages, setup


dependencies = ['click', 'mechanize', 'beautifulsoup4', 'configparser']

setup(
    name='python_spoj',
    version='0.5',
    url='https://github.com/DheerendraRathor/python_spoj',
    license='BSD',
    author='Dheerendra Rathor',
    author_email='dheeru.rathor14@gmail.com',
    description='An spoj library for python',
    long_description=__doc__,
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    install_requires=dependencies,
    entry_points={
        'console_scripts': [
            'spoj = spoj.cli:main',
        ],
    },
    classifiers=[
        # As from http://pypi.python.org/pypi?%3Aaction=list_classifiers
        # 'Development Status :: 1 - Planning',
        # 'Development Status :: 2 - Pre-Alpha',
        # 'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',
        # 'Development Status :: 5 - Production/Stable',
        # 'Development Status :: 6 - Mature',
        # 'Development Status :: 7 - Inactive',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX',
        'Operating System :: MacOS',
        'Operating System :: Unix',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)

==> python_spoj-0.5.1.tar.gz: python_spoj-0.5.1/setup.py <==
"""
An spoj library for python
"""
from setuptools import find_packages, setup


dependencies = ['click', 'mechanize', 'beautifulsoup4', 'configparser']

setup(
    name='python_spoj',
    version='0.5.1',
    url='https://github.com/DheerendraRathor/python-spoj',
    license='BSD',
    author='Dheerendra Rathor',
    author_email='dheeru.rathor14@gmail.com',
    description='An spoj library for python',
    long_description=__doc__,
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    install_requires=dependencies,
    entry_points={
        'console_scripts': [
            'spoj = spoj.cli:main',
        ],
    },
    classifiers=[
        # As from http://pypi.python.org/pypi?%3Aaction=list_classifiers
        # 'Development Status :: 1 - Planning',
        # 'Development Status :: 2 - Pre-Alpha',
        # 'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',
        # 'Development Status :: 5 - Production/Stable',
        # 'Development Status :: 6 - Mature',
        # 'Development Status :: 7 - Inactive',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: POSIX',
        'Operating System :: MacOS',
        'Operating System :: Unix',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
